==> Banners-2.5.1.tar.gz: Banners/action.deletecategory.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: Banners (c) 2008 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  An addon module for CMS Made Simple to allow management, display,
#  and tracking of banner images.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if (!$this->CheckPermission ('Manage Banners')) exit;

$this->SetCurrentTab('categories');

if( !isset( $params['category_id'] ) )
  {
    $this->SetError($this->Lang('error_insufficientparams'));
    $this->RedirectToTab($id);
  }

// test to see if there are still items left in this category, if there are, then puke
// otherwise delete the directory too (maybe)
$db =& $this->GetDb();
$query = "SELECT * FROM ".cms_db_prefix()."module_banners WHERE category_id = ?";
$dbresult = $db->Execute( $query, array( $params['category_id'] ) );
$c = $dbresult->RecordCount();
if( $dbresult->RecordCount() )
  {
    $this->SetError($this->Lang('error_categorynotempty'));
    $this->RedirectToTab($id);
  }

// we are free to delete the category
$query = "DELETE FROM ".cms_db_prefix()."module_banners_categories WHERE category_id = ?";

$dbresult = $db->Execute( $query, array( $params['category_id'] ) );
if( ! $dbresult ) {
  $this->SetError($this->Lang('error_dberror'));
 }

$this->RedirectToTab($id);

?>

==> Banners-2.5.3.tar.gz: Banners/action.deletecategory.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: Banners (c) 2008 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  An addon module for CMS Made Simple to allow management, display,
#  and tracking of banner images.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if (!$this->CheckPermission ('Manage Banners')) exit;

$this->SetCurrentTab('categories');

if( !isset( $params['category_id'] ) )
  {
    $this->SetError($this->Lang('error_insufficientparams'));
    $this->RedirectToTab($id);
  }

// test to see if there are still items left in this category, if there are, then puke
// otherwise delete the directory too (maybe)
$db = $this->GetDb();
$query = "SELECT * FROM ".cms_db_prefix()."module_banners WHERE category_id = ?";
$dbresult = $db->Execute( $query, array( $params['category_id'] ) );
$c = $dbresult->RecordCount();
if( $dbresult->RecordCount() )
  {
    $this->SetError($this->Lang('error_categorynotempty'));
    $this->RedirectToTab($id);
  }

// we are free to delete the category
$query = "DELETE FROM ".cms_db_prefix()."module_banners_categories WHERE category_id = ?";

$dbresult = $db->Execute( $query, array( $params['category_id'] ) );
if( ! $dbresult ) {
  $this->SetError($this->Lang('error_dberror'));
 }

$this->RedirectToTab($id);

?>
